@@ -76,6 +76,8 @@ class RedditImage:
         self.PADDING_THUMBNAIL = PADDING_THUMBNAIL or 5*DISTANCE
         self.COMMENT_OFFSET = COMMENT_OFFSET or 10*DISTANCE
 
+    def bg_image(self, width: int, height: int) -> Image:
+        return piu.image(width, height, self.COLOR_BG)
 
     def create_title(
         self,
